package com.docus.server.ws.impl;

import com.docus.core.util.json.JSON;
import com.docus.log.annotation.TrackGroup;
import com.docus.server.record.pojo.dto.TBasicDTO;
import com.docus.server.record.service.ITBasicService;
import com.docus.server.visitor.VisitorProcessor;
import com.docus.server.ws.IBasicService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.concurrent.atomic.AtomicReference;

/**
 * @BelongsProject: docus-webservice-sdry
 * @BelongsPackage: com.docus.server.collection.webservice
 * @Author: chierhao
 * @CreateTime: 2023-02-25  14:52
 * @Description: TODO
 * @Version: 1.0
 */
@Service
@Slf4j
public class BasicServiceImpl implements IBasicService {
    @Resource
    private ITBasicService tBasicService;
    private AtomicReference<TBasicDTO> atomicReference = new AtomicReference<>();

    /**
     * @param message 原始报文
     * @see com.docus.server.ws.convert.IConverter 通用转化器
     * @see com.docus.server.ws.IWsResult 通用返回结果
     * @see VisitorProcessor 通用处理器，aop环绕统一处理
     */
    @Override
    @TrackGroup(group = "WEBSERVICE_XML_BASIC",
            beanNames = {"tBasicConverter", "wsBasicResultImpl"}, processor = VisitorProcessor.class)
    public String setTBasic(String message) {
        log.info("新增基础数据：{}", message);
        tBasicService.insertTBasic(getTBasicDTO());
        return null;
    }

    /**
     * @param message 原始报文
     * @see com.docus.server.ws.convert.IConverter 通用转化器
     * @see com.docus.server.ws.IWsResult 通用返回结果
     * @see VisitorProcessor 通用处理器，aop环绕统一处理
     */
    @Override
    @TrackGroup(group = "WEBSERVICE_XML_BASIC",
            beanNames = {"tBasicConverter", "wsBasicResultImpl"}, processor = VisitorProcessor.class)
    public String updateTBasic(String message) {
        tBasicService.updateTBasic(getTBasicDTO());
        return null;
    }

    public void setProperty(String json) {
        this.atomicReference.set(JSON.fromJSON(json, TBasicDTO.class));
    }

    public TBasicDTO getTBasicDTO() {
        return atomicReference.get();
    }
}

