package com.docus.server.ws.impl;

import com.docus.core.util.json.JSON;
import com.docus.log.annotation.TrackGroup;
import com.docus.server.collect.service.CollectService;
import com.docus.server.sys.common.pojo.dto.DeptDTO;
import com.docus.server.visitor.VisitorProcessor;
import com.docus.server.ws.IDeptServer;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.concurrent.atomic.AtomicReference;

/**
 * @author wen yongbin
 * @date 2023年2月25日21:56:33
 */
@Service
@Slf4j
public class DeptServerImpl implements IDeptServer {
    @Resource
    private CollectService collectService;
    private AtomicReference<DeptDTO> atomicReference = new AtomicReference<>();

    /**
     * @param message 原始报文
     * @see com.docus.server.ws.convert.IConverter 通用转化器
     * @see com.docus.server.ws.IWsResult 通用返回结果
     * @see VisitorProcessor 通用处理器，aop环绕统一处理
     */
    @Override
    @TrackGroup(group = "WEBSERVICE_XML_DEPT",
            beanNames = {"powerDeptConverter", "wsDeptResultImpl"}, processor = VisitorProcessor.class)
    public String deptModify(String message) {
        log.info("新增/修改科室数据：{}", message);
        collectService.insertOrUpdateDept(getDeptDTO());
        return null;
    }

    public void setProperty(String json) {
        DeptDTO deptDTO = JSON.fromJSON(json, DeptDTO.class);
        this.atomicReference.set(deptDTO);
    }

    public DeptDTO getDeptDTO() {
        return this.atomicReference.get();
    }
}

