package com.docus.server.ws.impl;

import com.docus.core.util.json.JSON;
import com.docus.log.annotation.TrackGroup;
import com.docus.server.collect.service.CollectService;
import com.docus.server.sys.common.pojo.dto.UserDTO;
import com.docus.server.visitor.VisitorProcessor;
import com.docus.server.ws.IUserServer;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.concurrent.atomic.AtomicReference;

/**
 * @author wen yongbin
 * @date 2023年2月25日21:56:33
 */
@Service
@Slf4j
public class UserServerImpl implements IUserServer {
    @Resource
    private CollectService collectService;
    private AtomicReference<UserDTO> atomicReference = new AtomicReference<>();

    /**
     * @param message 原始报文
     * @see com.docus.server.ws.convert.IConverter 通用转化器
     * @see com.docus.server.ws.IWsResult 通用返回结果
     * @see VisitorProcessor 通用处理器，aop环绕统一处理
     */
    @Override
    @TrackGroup(group = "WEBSERVICE_XML_USER",
            beanNames = {"powerUserConverter", "wsUserResultImpl"}, processor = VisitorProcessor.class)
    public String userModify(String message) {
        log.debug("新增/修改用户数据：{}", message);
        collectService.insertOrUpdateUser(getUserDTO());
        return null;
    }

    public void setProperty(String json) {
        this.atomicReference.set(JSON.fromJSON(json, UserDTO.class));
    }

    public UserDTO getUserDTO() {
        return atomicReference.get();
    }
}

